@@ -4,46 +4,60 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
-use Moo;
+use Rope;
+use Rope::Autoload;
 use Term::Size::ReadKey;
 use Module::Load;
+use Types::Standard qw/Int Str Enum HashRef/;
 
 use overload "&{}" => sub {
 	my $self = shift; 
 	return sub { $self->render(@_); } 
 };
 
-has max_width => (
-	is => 'rw',
-	default => sub {
+property max_width => (
+	initable => 1,
+	writeable => 1,
+	type => Int,
+	builder => sub {
 		Term::Size::ReadKey::chars *STDOUT{IO};
 	}
 );
 
-has pad => (
-	is => 'rw',
-	default => sub { 0 }
+property pad => (
+	initable => 1,
+	writeable => 1,
+	type => Int,
+	value => 0,
 );
 
-has font => (
-	is => 'rw',
-	default => sub { 'Boomer' }
+property font => (
+	initable => 1,
+	writeable => 1,
+	type => Str,
+	value => 'Boomer'
 );
 
-has align => (
-	is => 'rw',
-	default => sub { 'left' }
+property align => (
+	initable => 1,
+	writeable => 1,
+	type => Enum[qw( left center right )],
+	value => 'left'
 );
 
-has color => (
-	is => 'rw'
+property color => (
+	initable => 1,
+	type => Str,
+	writeable => 1,
 );
 
-has color_map => (
-	is => 'rw',
-	default => sub { return {
+property color_map => (
+	initable => 1,
+	writeable => 1,
+	type => HashRef,
+	builder => sub { return {
 		black => "\e[30m",
 		red => "\e[31m",
 		green => "\e[32m",
@@ -63,13 +77,13 @@ has color_map => (
 	} }
 );
 
-sub font_class {
+function font_class => sub {
 	my $class = sprintf "Ascii::Text::Font::%s", $_[0]->font;
 	load $class;
 	return $class;
-}
+};
 
-sub render {
+function render => sub {
 	my ($self, $text) = @_;
 	my $class = $self->font_class->new;
 	my @words = split /\s+/, $text;
@@ -118,24 +132,21 @@ sub render {
 	if ($self->color && $self->color_map->{$self->color}) {
 		print "\e[0m";
 	}
-}
+};
 
-sub new_line {
+function new_line => sub {
 	return ($_[0]->max_width, [],[],[],[],[],[]);
-}
+};
 
-sub print_line {
+function print_line => sub {
 	my ($self, $line) = @_;
-
 	my $line_width = @{$line->[0]};
 	my $pad = $self->align eq 'center' 
 		? ($self->max_width - $line_width) / 2
 		: $self->align eq 'right'
 		? $self->max_width - $line_width
 		: $self->pad;
-
 	$pad = $pad ? " " x $pad : ""; 
-
 	for (@{$line}) {
 		if ($self->color && $self->color_map->{$self->color}) {
 			print $self->color_map->{$self->color};
@@ -144,7 +155,7 @@ sub print_line {
 		print join "", @{$_};
 		print "\n";
 	}
-}
+};
 
 1;
 
@@ -156,7 +167,7 @@ Ascii::Text - module for generating ASCII text in various fonts and styles
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =cut
 
