@@ -1,39 +1,41 @@
 package Ascii::Text::Font::Banner;
 
-use Moo;
+use Rope;
+use Rope::Autoload;
 
 extends 'Ascii::Text::Font';
 
-has character_height => (
-	is => 'ro',
-	default => sub { 7 }
+property character_height => (
+	initable => 0,
+	writeable => 0,
+	value => 7
 );
 
-sub character_A {
+function character_A => sub {
 	my @character = $_[0]->default_character(8);
 	$character[0][3] = $character[1][2] = $character[1][4] = $character[2][1] = $character[2][5] = $character[3][0] = $character[3][6] = $character[4][0] = $character[4][1] = $character[4][2] = $character[4][3] = $character[4][4] = $character[4][5] = $character[4][6] = $character[5][0] = $character[5][6] = $character[6][0] = $character[6][6] = '#';
 	return \@character;
-}
+};
 
-sub character_B {
+function character_B => sub {
 	my @character = $_[0]->default_character(8);
 	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3] = $character[0][4] = $character[0][5] = $character[0][6] = $character[1][0] = $character[1][6] = $character[2][0] = $character[2][6] = $character[3][0] = $character[3][1] = $character[3][2] = $character[3][3] = $character[3][5] = $character[4][0] = $character[4][6] = $character[5][0] = $character[5][6] = $character[6][0] = $character[6][1] = $character[6][2] = $character[6][3] = $character[6][4] = $character[6][5] = $character[6][6] = '#';
 	return \@character;
-}
+};
 
-sub character_C {
+function character_C => sub {
 	my @character = $_[0]->default_character(8);
 	$character[0][1] = $character[0][2] = $character[0][3] = $character[0][4] = $character[0][5] = $character[1][0] = $character[1][6] = $character[2][0] = $character[3][0] = $character[4][0] = $character[5][0] = $character[5][6] = $character[6][1] = $character[6][2] = $character[6][3] = $character[6][4] = $character[6][5] = '#';
 	return \@character;
-}
+};
 
-sub character_D {
+function character_D => sub {
 	my @character = $_[0]->default_character(8);
 	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3] = $character[0][4] = $character[0][5] = $character[1][0] = $character[1][6] = $character[2][0] = $character[2][6] = $character[3][0] = $character[3][6] = $character[4][0] = $character[4][6] = $character[5][0] = $character[5][6] = $character[6][0] = $character[6][1] = $character[6][2] = $character[6][3] = $character[6][4] = $character[6][5] = '#';
 	return \@character;
-}
+};
 
-sub character_E {
+function character_E => sub {
 	my @character = $_[0]->default_character(8);
 	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3] = $character[0][4] = $character[0][5] = $character[0][6] = '#';
 	$character[1][0] = '#';
@@ -43,15 +45,15 @@ sub character_E {
 	$character[5][0] = '#';
 	$character[6][0] = $character[6][1] = $character[6][2] = $character[6][3] = $character[6][4] = $character[6][5] = $character[6][6] = '#';
 	return \@character;
-}
+};
 
-sub character_F {
+function character_F => sub {
 	my @character = $_[0]->default_character(8);
 	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3] = $character[0][4] = $character[0][5] = $character[0][6] = $character[1][0] = $character[2][0] = $character[3][0] = $character[3][1] = $character[3][2] = $character[3][3] = $character[3][4] = $character[4][0] = $character[5][0] = $character[6][0] = '#';
 	return \@character;
-}
+};
 
-sub character_G {
+function character_G => sub {
 	my @character = $_[0]->default_character(8);
 	$character[0][0] = $character[0][1] = ' ';
 	$character[1][1] = $character[1][2] = $character[1][3] = $character[1][4] = $character[1][5] = ' ';
@@ -64,76 +66,76 @@ sub character_G {
 	$character[1][0] = $character[2][0] = $character[3][0] = $character[4][0] = $character[5][0] = $character[3][6] = $character[4][6] = $character[5][6] = '#';
 	$character[6][1] = $character[6][3] = $character[6][4] = $character[6][5] = $character[3][3] = $character[3][4] = $character[3][5] = $character[3][6] = '#';
 	return \@character;
-}
+};
 
-sub character_H {
+function character_H => sub {
 	my @character = $_[0]->default_character(8);
 	$character[0][0] = $character[1][0] = $character[2][0] = $character[3][0] = $character[4][0] = $character[5][0] = $character[6][0] = $character[3][1] = $character[3][2] = $character[3][3] = $character[3][4] = $character[3][5] = $character[3][6] = $character[0][6] = $character[1][6] = $character[2][6] = $character[4][6] = $character[5][6] = $character[6][6] = '#';
 	$character[0][0] = $character[1][0] = $character[2][0] = $character[3][0] = $character[4][0] = $character[5][0] = $character[6][0] = $character[3][1] = $character[3][2] = $character[3][3] = $character[3][4] = $character[3][5] = $character[3][6] = $character[0][6] = $character[1][6] = $character[2][6] = $character[4][6] = $character[5][6] = $character[6][6] = '#';
 	return \@character;
-}
+};
 
-sub character_I {
+function character_I => sub {
 	my @character = $_[0]->default_character(8);
 	$character[0][2] = $character[0][3] = $character[6][2] = $character[0][4] = $character[6][3] = $character[6][4] = $character[2][3] = $character[1][3] = $character[3][3] = $character[4][3] = $character[5][3] = '#';
 	return \@character;
-}
+};
 
-sub character_J {
+function character_J => sub {
 	my @character = $_[0]->default_character(8);
 	$character[0][6] = $character[1][6] = $character[2][6] = $character[3][6] = $character[4][6] = $character[5][6] = $character[6][5] = $character[6][4] = $character[6][3] = $character[6][2] = $character[6][1] = $character[5][0] = $character[4][0] = '#';
 	return \@character;
-}
+};
 
-sub character_K {
+function character_K => sub {
 	my @character = $_[0]->default_character(8);
 	$character[0][0] = $character[0][5] = $character[1][0] = $character[1][4] = $character[2][0] = $character[2][3] = $character[3][0] = $character[3][1] = $character[3][2] = $character[4][0] = $character[4][3] = $character[5][0] = $character[5][4] = $character[6][0] = $character[6][5] = '#';
 	return \@character;
-}
+};
 
-sub character_L {
+function character_L => sub {
 	my @character = $_[0]->default_character(8);
 	$character[0][0] = $character[1][0] = $character[2][0] = $character[3][0] = $character[4][0] = $character[5][0] = $character[6][0] = $character[6][1] = $character[6][2] = $character[6][3] = $character[6][4] = $character[6][5] = $character[6][6] = '#';
 	return \@character;
-}
+};
 
-sub character_M {
+function character_M => sub {
 	my @character = $_[0]->default_character(8);
 	$character[0][0] = $character[1][0] = $character[2][0] = $character[3][0] = $character[4][0] = $character[5][0] = $character[6][0] = $character[1][1] = $character[1][5] = $character[2][2] = $character[2][4] = $character[3][3] = $character[1][6] = $character[2][6] = $character[3][6] = $character[4][6] = $character[5][6] = $character[6][6] = $character[0][6] = '#';
 	return \@character;
-}
+};
 
-sub character_N {
+function character_N => sub {
 	my @character = $_[0]->default_character(8);
 	$character[0][0] = $character[1][0] = $character[2][0] = $character[3][0] = $character[4][0] = $character[5][0] = $character[6][0] = $character[0][6] = $character[1][6] = $character[2][6] = $character[3][6] = $character[4][6] = $character[5][6] = $character[6][6] = $character[1][1] = $character[2][2] = $character[3][3] = $character[4][4] = $character[5][5] = '#';
 	return \@character;
-}
+};
 
-sub character_O {
+function character_O => sub {
 	my @character = $_[0]->default_character(8);
 	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3] = $character[0][4] = $character[0][5] = $character[0][6] = $character[1][0] = $character[1][6] = $character[2][0] = $character[2][6] = $character[3][0] = $character[3][6] = $character[4][0] = $character[4][6] = $character[5][0] = $character[5][6] = $character[6][0] = $character[6][1] = $character[6][2] = $character[6][3] = $character[6][4] = $character[6][5] = $character[6][6] = '#';
 	return \@character;
-}
+};
 
-sub character_P {
+function character_P => sub {
 	my @character = $_[0]->default_character(8);
 	$character[0][0] = $character[1][0] = $character[2][0] = $character[3][0] = $character[4][0] = $character[5][0] = $character[6][0] = $character[0][1] = $character[0][2] = $character[0][3] = $character[0][4] = $character[0][5] = $character[1][6] = $character[2][6] = $character[3][1] = $character[3][2] = $character[3][3] = $character[3][4] = $character[3][5] = '#';
 	return \@character;
-}
+};
 
-sub character_Q {
+function character_Q => sub {
 	my @character = $_[0]->default_character(8);
 	$character[0][1] = $character[0][2] = $character[0][3] = $character[0][4] = $character[0][5] = $character[1][0] = $character[1][6] = $character[2][0] = $character[2][6] = $character[3][0] = $character[3][6] = $character[4][0] = $character[4][4] = $character[4][6] = $character[5][0] = $character[5][5] = $character[6][1] = $character[6][2] = $character[6][3] = $character[6][4] = $character[6][6] = '#';
 	return \@character;
-}
+};
 
-sub character_R {
+function character_R => sub {
 	my @character = $_[0]->default_character(8);
 	$character[0][0] = $character[1][0] = $character[2][0] = $character[3][0] = $character[4][0] = $character[5][0] = $character[6][0] = $character[0][1] = $character[0][2] = $character[0][3] = $character[0][4] = $character[0][5] = $character[1][6] = $character[2][6] = $character[3][1] = $character[3][2] = $character[3][3] = $character[3][4] = $character[3][5] = $character[4][4] = $character[5][5] = $character[6][6] = '#';
 	return \@character;
-}
+};
 
-sub character_S {
+function character_S => sub {
 	my @character = $_[0]->default_character(8);
 	$character[0][1] = $character[0][2] = $character[0][3] = $character[0][4] = $character[0][5] = '#';
 	$character[3][1] = $character[3][2] = $character[3][3] = $character[3][4] = $character[3][5] = '#';
@@ -143,276 +145,276 @@ sub character_S {
 	$character[4][6] = $character[5][6] = '#';
 	$character[5][0] = '#';
 	return \@character;
-}
+};
 
-sub character_T {
+function character_T => sub {
 	my @character = $_[0]->default_character(8);
 	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3] = '#';
 	$character[0][4] = $character[0][5] = $character[0][6] = '#';
 	$character[1][3] = $character[2][3] = $character[3][3] = $character[4][3] = '#';
 	$character[5][3] = $character[6][3] = '#';
 	return \@character;
-}
+};
 
-sub character_U {
+function character_U => sub {
 	my @character = $_[0]->default_character(8);
 	$character[0][0] = $character[1][0] = $character[2][0] = $character[3][0] = $character[4][0] = $character[5][0] = '#';
 	$character[0][6] = $character[1][6] = $character[2][6] = $character[3][6] = $character[4][6] = $character[5][6] = '#';
 	$character[6][1] = $character[6][2] = $character[6][3] = $character[6][4] = $character[6][5] = '#';
 	return \@character;
-}
+};
 
-sub character_V {
+function character_V => sub {
 	my @character = $_[0]->default_character(8);
 	$character[0][0] = $character[0][6] = $character[1][0] = $character[1][6] = $character[2][0] = $character[2][6] = $character[3][0] = $character[3][6] = '#';
 	$character[4][1] = $character[4][5] = $character[5][2] = $character[5][4] = $character[6][3] = '#';
 	return \@character;
-}
+};
 
-sub character_W {
+function character_W => sub {
 	my @character = $_[0]->default_character(8);
 	$character[0][0] = $character[1][0] = $character[2][0] = $character[3][0] = $character[4][0] = $character[5][0] = $character[0][6] = $character[1][6] = $character[2][6] = $character[3][6] = $character[4][6] = $character[5][6] = $character[1][3] = $character[2][3] = $character[3][3] = $character[4][3] = $character[5][3] = $character[6][1] = $character[6][2] = $character[6][4] = $character[6][5] = '#';
 	return \@character;
-}
+};
 
-sub character_X {
+function character_X => sub {
 	my @character = $_[0]->default_character(8);
 	$character[0][0] = $character[0][6] = $character[1][1] = $character[1][5] = $character[2][2] = $character[2][4] = $character[3][3] = $character[4][2] = $character[4][4] = $character[5][1] = $character[5][5] = $character[6][0] = $character[6][6] = '#';
 	return \@character;
-}
+};
 
-sub character_Y {
+function character_Y => sub {
 	my @character = $_[0]->default_character(8);
 	$character[3][3] = $character[4][3] = $character[5][3] = $character[6][3] = $character[0][0] = $character[0][6] = $character[1][1] = $character[1][5] = $character[2][2] = $character[2][4] = '#';
 	return \@character;
-}
+};
 
-sub character_Z {
+function character_Z => sub {
 	my @character = $_[0]->default_character(8);
 	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3] = $character[0][4] = $character[0][5] = $character[0][6] = $character[6][0] = $character[6][1] = $character[6][2] = $character[6][3] = $character[6][4] = $character[6][5] = $character[6][6] = $character[1][5] = $character[2][4] = $character[3][3] = $character[4][2] = $character[5][1] = '#';
 	return \@character;
-}
+};
 
-sub character_a {
+function character_a => sub {
 	my @character = $_[0]->default_character(5);
 	$character[3][1] = $character[3][2] = $character[3][3] = $character[4][0] = $character[4][3] = $character[5][0] = $character[5][2] = $character[5][3] = $character[6][1] = $character[6][3] = '#';
 	return \@character;
-}
+};
 
-sub character_b {
+function character_b => sub {
 	my @character = $_[0]->default_character(5);
 	$character[1][0] = $character[2][0] = $character[3][0] = $character[3][1] = $character[3][2] = $character[4][0] = $character[4][3] = $character[5][0] = $character[5][3] = $character[6][0] = $character[6][1] = $character[6][2] = '#';
 	return \@character;
-}
+};
 
-sub character_c {
+function character_c => sub {
 	my @character = $_[0]->default_character(5);
 	$character[3][1] = $character[3][2] = $character[4][0] = $character[5][0] = $character[6][2] = $character[6][1] = '#';
 	return \@character;
-}
+};
 
-sub character_d {
+function character_d => sub {
 	my @character = $_[0]->default_character(5);
 	$character[1][3] = $character[2][3] = $character[3][3] = $character[4][3] = $character[5][3] = $character[6][3] = '#';
 	$character[3][1] = $character[3][2] = $character[4][0] = $character[5][0] = $character[6][1] = $character[6][2] = '#';
 	return \@character;
-}
+};
 
-sub character_e {
+function character_e => sub {
 	my @character = $_[0]->default_character(6);
 	$character[3][1] = $character[3][2] = $character[4][0] = $character[4][2] = $character[4][3] = $character[5][0] = $character[5][1] = $character[6][1] = $character[6][2] = '#';
 	return \@character;
-}
+};
 
-sub character_f {
+function character_f => sub {
 	my @character = $_[0]->default_character(5);
 	$character[1][2] = $character[2][1] = $character[2][3] = $character[3][1] = $character[4][0] = $character[4][1] = $character[4][2] = $character[5][1] = $character[6][1] = '#';
 	return \@character;
-}
+};
 
-sub character_g {
+function character_g => sub {
 	my @character = $_[0]->default_character(5);
 	$character[2][1] = $character[2][2] = $character[2][3] = $character[3][0] = $character[3][3] = $character[4][1] = $character[4][2] = $character[5][0] = $character[6][1] = $character[6][2] = $character[6][3] = '#';
 	return \@character;
-}
+};
 
-sub character_h {
+function character_h => sub {
 	my @character = $_[0]->default_character(5);
 	$character[1][0] = $character[2][0] = $character[3][0] = $character[3][1] = $character[3][2] = $character[4][0] = $character[4][3] = $character[5][0] = $character[5][3] = $character[6][0] = $character[6][3] = '#';
 	return \@character;
-}
+};
 
-sub character_i {
+function character_i => sub {
 	my @character = $_[0]->default_character(5);
 	$character[1][1] = $character[3][1] = $character[3][0] = $character[4][1] = $character[5][1] = $character[6][0] = $character[6][1] = $character[6][2] = '#';
 	return \@character;
-}
+};
 
-sub character_j {
+function character_j => sub {
 	my @character = $_[0]->default_character(5);
 	$character[1][2] = $character[3][2] = $character[4][2] = $character[5][0] = $character[5][2] = $character[6][1] = '#';
 	return \@character;
-}
+};
 
-sub character_k {
+function character_k => sub {
 	my @character = $_[0]->default_character(5);
 	$character[1][0] = $character[2][0] = $character[3][0] = $character[4][0] = $character[5][0] = $character[6][0] = $character[3][2] = $character[4][1] = $character[5][2] = $character[6][3] = '#';
 	return \@character;
-}
+};
 
-sub character_l {
+function character_l => sub {
 	my @character = $_[0]->default_character(4);
 	$character[1][0] = $character[1][1] = $character[2][1] = $character[3][1] = $character[4][1] = $character[5][1] = $character[6][0] = $character[6][1] = $character[6][2] = '#';
 	return \@character;
-}
+};
 
-sub character_m {
+function character_m => sub {
 	my @character = $_[0]->default_character(7);
 	$character[4][0] = $character[5][0] = $character[6][0] = $character[3][1] = $character[3][4] = $character[4][2] = $character[4][3] = $character[4][5] = $character[6][5] = $character[5][5] = '#';
 
 	return \@character;
-}
+};
 
-sub character_n {
+function character_n => sub {
 	my @character = $_[0]->default_character(4);
 	$character[3][0] = $character[3][1] = $character[3][2] = $character[4][0] = $character[4][3] = $character[5][0] = $character[5][3] = $character[6][0] = $character[6][3] = '#';
 	return \@character;
-}
+};
 
-sub character_o {
+function character_o => sub {
 	my @character = $_[0]->default_character(6);
 	$character[3][2] = $character[3][3] = $character[4][1] = $character[4][4] = $character[5][1] = $character[5][4] = $character[6][2] = $character[6][3] = '#';
 	return \@character;
-}
+};
 
-sub character_p {
+function character_p => sub {
 	my @character = $_[0]->default_character(4);
 	$character[2][0] = $character[2][1] = $character[2][2] = $character[3][0] = $character[4][0] = $character[5][0] = $character[5][1] = $character[5][2] = $character[6][0] = $character[3][3] = $character[4][3] = '#';
 	return \@character;
-}
+};
 
-sub character_q {
+function character_q => sub {
 	my @character = $_[0]->default_character(8);
 	$character[2][3] = $character[2][4] = $character[2][5]  = $character[3][2] = $character[3][6] = $character[4][2] = $character[4][6] = $character[5][3] = $character[5][4] = $character[5][5]  = $character[6][6] = '#';
 	
 	return \@character;
-}
+};
 
-sub character_r {
+function character_r => sub {
 	my @character = $_[0]->default_character(5);
 	$character[3][0] = $character[3][1] = $character[3][2] = $character[4][0] = $character[5][0] = $character[6][0] = $character[4][3] = '#';		
 	return \@character;
-}
+};
 
-sub character_s {
+function character_s => sub {
 	my @character = $_[0]->default_character(5);
 	$character[3][1] = $character[3][2] = $character[3][3] = $character[4][0] = $character[4][1] = $character[5][2] = $character[5][3] = $character[6][0] =$character[6][1] = $character[6][2]  = '#';
 	return \@character;
-}
+};
 
-sub character_t {
+function character_t => sub {
 	my @character = $_[0]->default_character(5);
 	$character[1][1] = $character[2][1] = $character[3][0] = $character[3][1] = $character[3][2] = $character[4][1] = $character[5][1] = $character[6][2] = $character[6][3] = '#';
 	return \@character;
-}
+};
 
-sub character_u {
+function character_u => sub {
 	my @character = $_[0]->default_character(5);
 	$character[3][0] = $character[3][3] = $character[4][0] = $character[4][3] = $character[5][0] = $character[5][3] = $character[6][1] = $character[6][2] = $character[6][3] = '#';
 
 	return \@character;
-}
+};
 
-sub character_v {
+function character_v => sub {
 	my @character = $_[0]->default_character(6);
 	$character[3][0] = $character[4][0] = $character[5][1] = $character[6][2] = $character[5][3] = $character[4][4] = $character[3][4] = '#';
 	return \@character;
-}
+};
 
-sub character_w {
+function character_w => sub {
 	my @character = $_[0]->default_character(6);
 	$character[3][0] = $character[3][4] = $character[4][0] = $character[4][4] = $character[5][0] = $character[5][2] = $character[5][4] = $character[6][0] = $character[6][1] = $character[6][3] = $character[6][4] = '#';
 	return \@character;
-}
+};
 
-sub character_x {
+function character_x => sub {
 	my @character = $_[0]->default_character(5);
 	$character[3][0] = $character[3][3] = $character[4][1] = $character[4][2] = $character[5][1] = $character[5][2] = $character[6][0] = $character[6][3] = '#';
 	return \@character;
-}
+};
 
-sub character_y {
+function character_y => sub {
 	my @character = $_[0]->default_character(5);
 	$character[3][0] = $character[3][3] = $character[4][1] = $character[4][3] = $character[5][2] = $character[6][1] = '#';
 
 	return \@character;
-}
+};
 
-sub character_z {
+function character_z => sub {
 	my @character = $_[0]->default_character(5);
 	$character[3][0] = $character[3][1] = $character[3][2] = $character[3][3] = $character[4][2] = $character[5][1] = $character[6][0] = $character[6][1] = $character[6][2] = $character[6][3] ='#';
 	return \@character;
-}
+};
 
-sub character_0 {
+function character_0 => sub {
 	my @character = $_[0]->default_character(8);
 	$character[0][2] = $character[0][3] = $character[0][4] = $character[1][1] = $character[1][5] = $character[2][0] = $character[2][6] = $character[3][0] = $character[3][6] = $character[4][0] = $character[4][6] = $character[5][1] = $character[5][5] = $character[6][2] = $character[6][3] = $character[6][4] = '#';
 	return \@character;
-}
+};
 
-sub character_1 {
+function character_1 => sub {
 	my @character = $_[0]->default_character(6);
 	$character[0][2] = $character[1][2] = $character[2][2] = $character[3][2] = $character[4][2] = $character[5][2] = $character[6][2] = '#';
 	$character[6][0] = $character[6][1] = $character[6][3] = $character[6][4] = '#';
 	$character[2][0] = $character[1][1] = '#';
 	return \@character;
-}
+};
 
-sub character_2 {
+function character_2 => sub {
 	my @character = $_[0]->default_character(8);
 	$character[0][1]=$character[0][2]=$character[0][3]=$character[0][4]=$character[0][5]=$character[1][0]=$character[1][6]=$character[2][6]=$character[3][5]=$character[3][4]=$character[3][3]='#';
 	$character[3][2]=$character[3][1]='#';
 	$character[4][0]=$character[5][0]=$character[6][0]=$character[6][1]=$character[6][2]=$character[6][3]='#';
 	$character[6][4]=$character[6][5]=$character[6][6]='#';
 	return \@character;
-}
+};
 
-sub character_3 {
+function character_3 => sub {
 	my @character = $_[0]->default_character(8);
 	$character[0][1] = $character[0][2] = $character[0][3] = $character[0][4] = $character[0][5] = $character[1][0] = $character[1][6] = '#';
 	$character[2][6] = $character[3][1] = $character[3][2] = $character[3][3] = $character[3][4] = $character[3][5] = $character[4][6] = '#';
 	$character[5][0] = $character[6][1] = $character[5][6] = $character[6][2] = $character[6][3] = $character[6][4] = $character[6][5] = '#';
 	return \@character;
-}
+};
 
-sub character_4 {
+function character_4 => sub {
 	my @character = $_[0]->default_character(8);
 	$character[0][0] = $character[1][0] = $character[2][0] = $character[3][0] = '#';
 	$character[1][5] = $character[2][5] = $character[3][5] = '#';
 	$character[4][1] = $character[4][2] = $character[4][3] = $character[4][4] = $character[4][5] = $character[4][6] = '#';
 	$character[5][5] = $character[6][5] = '#';
 	return \@character;
-}
+};
 
-sub character_5 {
+function character_5 => sub {
 	my @character = $_[0]->default_character(8);
 	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3] = $character[0][4] = $character[0][5] = $character[0][6] = $character[1][0] = $character[2][0] = $character[3][0] = $character[3][1] = $character[3][2] = $character[3][3] = $character[3][4] = $character[3][5] = $character[4][6] = $character[5][0] = $character[5][6] = $character[6][1] = $character[6][2] = $character[6][3] = $character[6][4] = $character[6][5] = '#';
 	return \@character;
-}
+};
 
-sub character_6 {
+function character_6 => sub {
 	my @character = $_[0]->default_character(8);
 	$character[0][1] = $character[0][2] = $character[0][3] = $character[0][4] = $character[0][5] = $character[1][0] = $character[1][6] = $character[2][0] = $character[3][0] = $character[3][1] = $character[3][2] = $character[3][3] = $character[3][4] = $character[3][5] = $character[4][0] = $character[4][6] = $character[5][0] = $character[5][6] = $character[6][1] = $character[6][2] = $character[6][3] = $character[6][4] = $character[6][5] = '#';
 	return \@character;
-}
+};
 
-sub character_7 {
+function character_7 => sub {
 	my @character = $_[0]->default_character(8);
 	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3] = $character[0][4] = $character[0][5] = $character[0][6] = $character[1][0] = $character[1][5] = $character[2][4] = $character[3][3] = $character[4][2] = $character[5][2] = $character[6][2] = '#';
 	return \@character;
-}
+};
 
-sub character_8 {
+function character_8 => sub {
 	my @character = $_[0]->default_character(8);
 	$character[0][1] = $character[0][2] = $character[0][3] = $character[0][4] = $character[0][5] = '#';
 	$character[3][1] = $character[3][2] = $character[3][3] = $character[3][4] = $character[3][5] = '#';
@@ -420,18 +422,18 @@ sub character_8 {
 	$character[1][0] = $character[2][0] = $character[4][0] = $character[5][0] = '#';
 	$character[1][6] = $character[2][6] = $character[4][6] = $character[5][6] = '#';
 	return \@character;
-}
+};
 
-sub character_9 {
+function character_9 => sub {
 	my @character = $_[0]->default_character(8);
 	$character[0][1] = $character[0][2] = $character[0][3] = $character[0][4] = $character[0][5] = $character[1][0] = $character[1][6] = $character[2][0] = $character[2][6] = $character[3][1] = $character[3][2] = $character[3][3] = $character[3][4] = $character[3][5] = $character[3][6] = $character[4][6] = $character[5][0] = $character[5][6] = $character[6][1] = $character[6][2] = $character[6][3] = $character[6][4] = $character[6][5] = $character[6][6] = '#';
 	return \@character;
-}
+};
 
-sub space {
+function space => sub {
 	my @character = $_[0]->default_character(8);
 	return \@character;
-}
+};
 
 1;
 
@@ -439,19 +441,19 @@ __END__
 
 =head1 NAME
 
-Ascii::Text::Font::Boomer - Boomer font
+Ascii::Text::Font::Banner - Banner font
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =cut
 
 =head1 SYNOPSIS
 
-	use Ascii::Text::Font::Boomer;
+	use Ascii::Text::Font::Banner;
 
-	my $font = Ascii::Text::Font::Boomer->new();
+	my $font = Ascii::Text::Font::Banner->new();
 
 	$font->character_A;
 
@@ -465,6 +467,7 @@ Instantiate a new Ascii::Text::Font::Boomer object.
 
 =head2 character_A
 
+todo
 
 =head2 character_B
 
